from flask import flash, redirect, render_template, url_for
from flask_login import login_required, login_user
from . import main
from ..auth.forms import LoginForm
from ..models import User


@main.route('/', methods=['GET', 'POST'])
def index():
    login_form = LoginForm(prefix='login-form')
    if login_form.validate_on_submit():
        user = User.query.filter_by(username=login_form.user.data).first()
        if user is None:
            user = User.query.filter_by(email=login_form.user.data).first()
        if user is not None and user.verify_password(login_form.password.data):
            login_user(user, login_form.remember_me.data)
            return redirect(url_for('main.dashboard'))
        flash('Invalid email/username or password.')
    return render_template('main/index.html.j2', login_form=login_form,
                           title='nopaque')


@main.route('/about_and_faq')
def about_and_faq():
    return render_template('main/about_and_faq.html.j2', title='About and faq')


@main.route('/dashboard')
@login_required
def dashboard():
    return render_template('main/dashboard.html.j2', title='Dashboard')



@main.route('/news')
def news():
    return render_template('main/news.html.j2', title='News')


@main.route('/privacy_policy')
def privacy_policy():
    return render_template('main/privacy_policy.html.j2',
                           title=('Information on the processing of personal'
                                  ' data for the nopaque platform (GDPR)'))


@main.route('/terms_of_use')
def terms_of_use():
    return render_template('main/terms_of_use.html.j2',
                           title='General Terms of Use of the platform '
                                 'nopaque')
